<?php

namespace AuthStack\Driver\AUDGeneric\App\Controllers;

use Exception;
use AuthStack\Driver\AUDGeneric\Driver;
use AuthStack\Http\Controllers\Controller;
use AuthStack\Driver\AUDGeneric\App\Requests\Import;

class AUDImport extends Controller
{
    protected $driver;

    public function __construct()
    {
        $this->driver = new Driver();
    }

    /**
     * @param Import $request
     * @throws Exception
     */
    public function import(Import $request)
    {
        $account = $this->driver->authenticate($request->getFormParams());

        \Log::info('AUD::Import::Account', [$account]);
    }
}